@@ -30,10 +30,6 @@ describe 'nova' do
         :refreshonly => true
       )}
 
-      it 'does not configure glance api servers' do
-        is_expected.to_not contain_nova_config('glance/api_servers')
-      end
-
       it 'does not configure auth_strategy' do
         is_expected.not_to contain_nova_config('api/auth_strategy')
       end
@@ -69,10 +65,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/dhcp_domain').with_value('<SERVICE DEFAULT>')
       end
 
-      it 'configures block_device_allocate params' do
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('<SERVICE DEFAULT>')
-      end
     end
 
     context 'with overridden parameters' do
@@ -81,7 +73,6 @@ describe 'nova' do
         {
           :glance_endpoint_override                => 'http://localhost:9292',
           :glance_num_retries                      => 3,
-          :glance_api_servers                      => ['http://localhost:9292', 'http://localhost:9293'],
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :control_exchange                        => 'nova',
@@ -109,8 +100,6 @@ describe 'nova' do
           :upgrade_level_network                   => '1.0.0',
           :upgrade_level_scheduler                 => '1.0.0',
           :purge_config                            => false,
-          :block_device_allocate_retries           => '60',
-          :block_device_allocate_retries_interval  => '3',
           :my_ip                                   => '192.0.2.1',
           :ssl_only                                => true,
           :cert                                    => '/etc/ssl/private/snakeoil.pem',
@@ -139,7 +128,6 @@ describe 'nova' do
       it 'configures glance parameters' do
         is_expected.to contain_nova_config('glance/endpoint_override').with_value('http://localhost:9292')
         is_expected.to contain_nova_config('glance/num_retries').with_value(3)
-        is_expected.to contain_nova_config('glance/api_servers').with_value(['http://localhost:9292', 'http://localhost:9293'])
       end
 
       it 'configures auth_strategy' do
@@ -200,11 +188,6 @@ describe 'nova' do
           ['ceilometer.compute.nova_notifier', 'nova.openstack.common.notifier.rpc_notifier']
         ) }
       end
-
-      it 'configures block_device_allocate params' do
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries').with_value('60')
-        is_expected.to contain_nova_config('DEFAULT/block_device_allocate_retries_interval').with_value('3')
-      end
     end
 
     context 'with wrong notify_on_state_change parameter' do
