@@ -46,9 +46,20 @@ describe 'nova::keystone::auth' do
       )}
     end
 
+    context 'when overriding roles' do
+      before do
+        params.merge!( :roles => ['admin', 'service'] )
+      end
+
+      it { should contain_keystone_user_role('nova@services').with(
+        :ensure => 'present',
+        :roles  => ['admin', 'service']
+      )}
+    end
+
     context 'when setting auth name' do
       before do
-         params.merge!( :auth_name => 'foo' )
+        params.merge!( :auth_name => 'foo' )
       end
 
       it { should contain_keystone_user('foo').with(
@@ -141,7 +152,7 @@ describe 'nova::keystone::auth' do
 
     context 'when configuring nova-api and the keystone endpoint' do
       let :pre_condition do
-        "class { '::nova::keystone::authtoken':
+        "class { 'nova::keystone::authtoken':
            password => 'secrete',
          }
          class { 'nova::api': }
@@ -155,7 +166,7 @@ describe 'nova::keystone::auth' do
         }
       end
 
-      it { should contain_keystone_endpoint('RegionOne/nova::compute').with_notify(platform_params[:nova_api_notify]) }
+      it { should contain_keystone_endpoint('RegionOne/nova::compute').with_before(['Anchor[nova::service::end]']) }
     end
   end
 
@@ -167,19 +178,6 @@ describe 'nova::keystone::auth' do
         facts.merge!(OSDefaults.get_facts())
       end
 
-      let (:platform_params) do
-        case facts[:osfamily]
-        when 'Debian'
-          {
-            :nova_api_notify => ['Service[nova-api]'],
-          }
-        when 'RedHat'
-          {
-            :nova_api_notify => [],
-          }
-        end
-      end
-
       it_behaves_like 'nova::keystone::auth'
     end
   end
